Balance class

The user balance

Constructors

Balance(String json)
Create a new balance object

Properties

hashCode int
The hash code for this object.
no setterinherited
info Map<String, dynamic>
The user balance object
no setter
json String
Raw JSON response
final
map Map<String, dynamic>
Parsed JSON response
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited