Completion class
The completion response
Constructors
- Completion(String json)
- Create a new completion object
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- json → String
-
Raw JSON response
final
-
map
→ Map<
String, dynamic> -
Parsed JSON response
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The completion text
no setter
- textUtf8 → String
-
The completion text rencoded as UTF-8 (chinese)
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited