DeepSeek class

The DeepSeek client

Constructors

DeepSeek(String apiKey, {String baseUrl = 'https://api.deepseek.com'})
Initialize DeepSeek client with your API key

Properties

apiKey String
your DeepSeek API key
final
baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createChat({required List<Message> messages, String? model, Map<String, dynamic>? options}) Future<Completion>
https://api-docs.deepseek.com/api/create-chat-completion
getUserBalance() Future<Balance>
https://api-docs.deepseek.com/api/get-user-balance
listModels() Future<List<String>>
https://api-docs.deepseek.com/api/list-models
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited