DeepSeekException class

Represents a DeepSeek API error

Implemented types

Constructors

DeepSeekException(String message, {int? statusCode, String? type, String? param, String? code})
DeepSeekException.fromBody(String body, int statusCode)
DeepSeekException.fromMap(Map<String, dynamic> map, {int? statusCode})

Properties

code String?
The error code
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
final
param String?
The error parameter
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The error status code
final
type String?
The error type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited