textUtf8 property
The completion text rencoded as UTF-8 (chinese)
Only use this if you have issues with .text
Implementation
@Deprecated('not needed anymore, but kept for backward compatibility')
String get textUtf8 => fixUtf8(text);
The completion text rencoded as UTF-8 (chinese)
Only use this if you have issues with .text
@Deprecated('not needed anymore, but kept for backward compatibility')
String get textUtf8 => fixUtf8(text);