Message class

Constructors

Message({required dynamic content, required String role, String? name})
Create a new message
Message.fromJson(String source)
factory
Message.fromMap(Map<String, dynamic> map)
factory
Message.multimodal({required String text, required String imageUrl, required String role, String? name})
Helper method to create a multimodal message with image
factory
Message.text({required String content, required String role, String? name})
Helper method to create a text message
factory

Properties

content → dynamic
The message content - can be String or List
final
hashCode int
The hash code for this object.
no setteroverride
hasImages bool
Check if message contains images
no setter
name String?
The message name
final
role String
The message role
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textContent String?
Get text content from message
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override